@@ -1,5 +1,3 @@
-from contextlib import suppress
-from importlib import metadata
 from os import system as shell
 
 from stylegan2_torch.discriminator import Discriminator
@@ -10,7 +8,7 @@ from stylegan2_torch.utils import Resolution, default_channels
 
 __author__ = "Peter Yuen"
 __email__ = "ppeetteerrsx@gmail.com"
-__version__ = "1.2.0"
+__version__ = "1.3.0"
 
 
 __all__ = [
